pub fn lower_contract(node: &ContractNode) -> Result<Contract>Expand description
Convert a parsed AST into a runtime Contract struct. This is the bridge between the parser output and the executor input.
pub fn lower_contract(node: &ContractNode) -> Result<Contract>Convert a parsed AST into a runtime Contract struct. This is the bridge between the parser output and the executor input.